@@ -22,8 +22,7 @@ use crate::messaging::{
     AuthorityProof, DstLocation, MsgId, MsgKind, MsgType, ServiceAuth, WireMsg,
 };
 use crate::node::SectionAuthorityProvider;
-use crate::peer::Peer;
-use crate::types::{log_markers::LogMarker, utils::compare_and_write_prefix_map_to_disk};
+use crate::types::{log_markers::LogMarker, utils::compare_and_write_prefix_map_to_disk, Peer};
 
 use bytes::Bytes;
 use itertools::Itertools;
