@@ -8,16 +8,14 @@
 
 use super::{QueryResult, Session};
 
-use crate::client::connections::CmdResponse;
-use crate::client::Error;
+use crate::client::{connections::CmdResponse, Error};
 use crate::elder_count;
 use crate::messaging::{
     data::{CmdError, DataQuery, QueryResponse},
     DstLocation, MsgId, MsgKind, ServiceAuth, WireMsg,
 };
-use crate::peer::Peer;
-use crate::prefix_map::NetworkPrefixMap;
-use crate::types::PublicKey;
+use crate::types::{prefix_map::NetworkPrefixMap, Peer, PublicKey};
+
 use backoff::{backoff::Backoff, ExponentialBackoff};
 use bytes::Bytes;
 use dashmap::DashMap;
@@ -157,7 +155,7 @@ impl Session {
         let mut received_ack = 0;
         let mut received_err = 0;
         let mut attempts = 0;
-        let interval = Duration::from_millis(100);
+        let interval = Duration::from_millis(1000);
         let expected_cmd_ack_wait_attempts =
             std::cmp::max(10, self.cmd_ack_wait.as_millis() / interval.as_millis());
         loop {
@@ -201,7 +199,7 @@ impl Session {
                 break;
             }
             trace!(
-                "current attempt {:?}/{:?}",
+                "current ack waiting loop count {:?}/{:?}",
                 attempts,
                 expected_cmd_ack_wait_attempts
             );
