@@ -7,38 +7,30 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 mod api;
-mod back_pressure;
 mod bootstrap;
-mod capacity;
 mod comm;
 mod connectivity;
-mod data_records;
-mod data_storage;
+mod data;
 mod delivery_group;
-mod liveness_tracking;
 mod messaging;
-mod msg_count;
-mod msg_handling;
 mod proposal;
 mod relocation;
 mod split_barrier;
 
-pub(crate) use back_pressure::BackPressure;
 pub(crate) use bootstrap::{join_network, JoiningAsRelocated};
-pub(crate) use capacity::MIN_LEVEL_WHEN_FULL;
 pub(crate) use comm::{Comm, ConnectionEvent, SendStatus};
+pub(crate) use data::MIN_LEVEL_WHEN_FULL;
 pub(crate) use proposal::Proposal;
 #[cfg(test)]
 pub(crate) use relocation::{check as relocation_check, ChurnId};
 
-use self::{data_storage::DataStorage, split_barrier::SplitBarrier};
+use self::{data::DataStorage, split_barrier::SplitBarrier};
 
 use super::{
     api::cmds::Cmd,
     dkg::DkgVoter,
     network_knowledge::{NetworkKnowledge, SectionKeyShare, SectionKeysProvider},
-    node_info::Node,
-    Elders, Event, NodeElderChange,
+    Elders, Event, NodeElderChange, NodeInfo,
 };
 
 use crate::messaging::{
@@ -48,14 +40,14 @@ use crate::messaging::{
     AuthorityProof, SectionAuth,
 };
 use crate::node::error::Result;
-use crate::peer::Peer;
-use crate::types::{log_markers::LogMarker, utils::compare_and_write_prefix_map_to_disk, Cache};
+use crate::types::{
+    log_markers::LogMarker, utils::compare_and_write_prefix_map_to_disk, Cache, Peer,
+};
 use crate::UsedSpace;
 
 use backoff::ExponentialBackoff;
-use capacity::Capacity;
+use data::{Capacity, Liveness};
 use itertools::Itertools;
-use liveness_tracking::Liveness;
 use resource_proof::ResourceProof;
 use std::{
     collections::{BTreeMap, BTreeSet, HashMap},
@@ -101,34 +93,44 @@ pub(crate) struct DkgSessionInfo {
 }
 
 // Core state + logic of a node.
-pub(crate) struct Core {
+pub(crate) struct Node {
+    pub(super) event_tx: mpsc::Sender<Event>,
+    pub(crate) info: Arc<RwLock<NodeInfo>>,
+
     pub(crate) comm: Comm,
-    pub(crate) node: Arc<RwLock<Node>>,
-    network_knowledge: NetworkKnowledge,
     pub(crate) section_keys_provider: SectionKeysProvider,
+
+    pub(super) data_storage: DataStorage, // Adult only before cache
+
+    resource_proof: ResourceProof,
+
+    network_knowledge: NetworkKnowledge,
+
     message_aggregator: SignatureAggregator,
+
     proposal_aggregator: SignatureAggregator,
     split_barrier: Arc<RwLock<SplitBarrier>>,
     dkg_sessions: Arc<RwLock<HashMap<DkgSessionId, DkgSessionInfo>>>,
     dkg_voter: DkgVoter,
+
     relocate_state: Arc<RwLock<Option<Box<JoiningAsRelocated>>>>,
-    pub(super) event_tx: mpsc::Sender<Event>,
-    joins_allowed: Arc<RwLock<bool>>,
-    current_joins_semaphore: Arc<Semaphore>,
-    resource_proof: ResourceProof,
-    pub(super) data_storage: DataStorage,
-    capacity: Capacity,
-    liveness: Liveness,
-    pending_data_queries: Arc<Cache<OperationId, Vec<Peer>>>,
+
+    joins_allowed: Arc<RwLock<bool>>,        // Elder only
+    current_joins_semaphore: Arc<Semaphore>, // Elder only
+
+    capacity: Capacity,                                       // Elder only
+    liveness: Liveness,                                       // Elder only
+    pending_data_queries: Arc<Cache<OperationId, Vec<Peer>>>, // Elder only
+
     ae_backoff_cache: AeBackoffCache,
 }
 
-impl Core {
+impl Node {
     // Creates `Core` for a regular node.
     #[allow(clippy::too_many_arguments)]
     pub(crate) async fn new(
         comm: Comm,
-        mut node: Node,
+        mut info: NodeInfo,
         network_knowledge: NetworkKnowledge,
         section_key_share: Option<SectionKeyShare>,
         event_tx: mpsc::Sender<Event>,
@@ -138,7 +140,7 @@ impl Core {
         let section_keys_provider = SectionKeysProvider::new(section_key_share).await;
 
         // make sure the Node has the correct local addr as Comm
-        node.addr = comm.our_connection_info();
+        info.addr = comm.our_connection_info();
 
         let data_storage = DataStorage::new(&root_storage_dir, used_space.clone())?;
 
@@ -155,7 +157,7 @@ impl Core {
 
         Ok(Self {
             comm,
-            node: Arc::new(RwLock::new(node)),
+            info: Arc::new(RwLock::new(info)),
             network_knowledge,
             section_keys_provider,
             dkg_sessions: Arc::new(RwLock::new(HashMap::default())),
@@ -180,15 +182,6 @@ impl Core {
     // Miscellaneous
     ////////////////////////////////////////////////////////////////////////////
 
-    pub(crate) async fn state_snapshot(&self) -> StateSnapshot {
-        StateSnapshot {
-            is_elder: self.is_elder().await,
-            section_key: self.network_knowledge.section_key().await,
-            prefix: self.network_knowledge.prefix().await,
-            elders: self.network_knowledge().authority_provider().await.names(),
-        }
-    }
-
     pub(crate) async fn generate_probe_msg(&self) -> Result<Cmd> {
         // Generate a random address not belonging to our Prefix
         let mut dst = XorName::random();
@@ -229,8 +222,17 @@ impl Core {
         });
     }
 
+    pub(super) async fn state_snapshot(&self) -> StateSnapshot {
+        StateSnapshot {
+            is_elder: self.is_elder().await,
+            section_key: self.network_knowledge.section_key().await,
+            prefix: self.network_knowledge.prefix().await,
+            elders: self.network_knowledge().authority_provider().await.names(),
+        }
+    }
+
     /// Generate cmds and fire events based upon any node state changes.
-    pub(crate) async fn update_self_for_new_node_state(
+    pub(super) async fn update_self_for_new_node_state(
         &self,
         old: StateSnapshot,
     ) -> Result<Vec<Cmd>> {
@@ -355,7 +357,7 @@ impl Core {
         Ok(cmds)
     }
 
-    pub(crate) async fn section_key_by_name(&self, name: &XorName) -> bls::PublicKey {
+    pub(super) async fn section_key_by_name(&self, name: &XorName) -> bls::PublicKey {
         if self.network_knowledge.prefix().await.matches(name) {
             self.network_knowledge.section_key().await
         } else if let Ok(sap) = self.network_knowledge.section_by_name(name) {
@@ -378,7 +380,7 @@ impl Core {
         }
     }
 
-    pub(crate) async fn print_network_stats(&self) {
+    pub(super) async fn print_network_stats(&self) {
         self.network_knowledge
             .prefix_map()
             .network_stats(&self.network_knowledge.authority_provider().await)
